@@ -1443,4 +1443,55 @@ class ILobbyMatchmakingService(_SteamAPI):
             "steamid_lobby": steamid_lobby
         }
 
-        return self._get("ILobbyMatchmakingService", "GetLobbyData", 1, params)
\ No newline at end of file
+        return self._get("ILobbyMatchmakingService", "GetLobbyData", 1, params)
+
+
+class ISiteLicenseService(_SteamAPI):
+    """
+    Provides access to services related
+    to operating sites which are part of the
+    Steam PC Cafe program.
+    """
+    def __init__(self, key: str):
+        super().__init__(key)
+
+    def get_current_client_connections(self,
+                                    siteid: int = 0,
+                                    ):
+        """
+        See current activity at one or more sites.
+
+        :param siteid: Site ID to see; zero for all sites
+        :type siteid: int
+        :return: Steam API response
+        """
+
+        params = {
+            "siteid": siteid
+        }
+
+        return self._get("ISiteLicenseService", "GetCurrentClientConnections", 1, params)
+
+    def get_total_playtime(self,
+                         start_time: str,
+                         end_time: str,
+                         siteid: int = 0):
+        """
+        Get total playtime amounts for all games over a period of time; for one or all sites.
+
+        :param start_time: Report activity starting on or after this time. RFC 3339 UTC format.
+        :type start_time: str
+        :param end_time: Report activity starting before this time. RFC 3339 UTC format.
+        :type end_time: str
+        :param siteid: Site ID to see; zero for all sites
+        :type siteid: int
+        :return: Steam API response
+        """
+
+        param = {
+            "start_time": start_time,
+            "end_time": end_time,
+            "siteid": siteid
+        }
+
+        return self._get("ISiteLicenseService", "GetTotalPlaytime", 1, param)
